var servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1ClipboardManager =
[
    [ "com::sun::star::lang::XComponent", "servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1ClipboardManager.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
    [ "XClipboardManager", "servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1ClipboardManager.html#af56defbe333bada13ce19604e1091162", null ]
];